/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Charts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "datasource.h"
#include <QtCharts/QLineSeries>
#include <QtCharts/QAreaSeries>
#include <QtQuick/QQuickView>
#include <QtQuick/QQuickItem>
#include <QtCore/QDebug>
#include <QtCore/QtMath>
#include <QDateTime>

QT_CHARTS_USE_NAMESPACE

Q_DECLARE_METATYPE(QAbstractSeries *)
Q_DECLARE_METATYPE(QAbstractAxis *)

DataSource::DataSource(QQuickView *appViewer, QObject *parent) :
    QObject(parent),
    m_appViewer(appViewer)
{
    qRegisterMetaType<QAbstractSeries*>();
    qRegisterMetaType<QAbstractAxis*>();
    m_nShowCurve = 0;
    m_dYCurveMax = 1;
    m_dYTempMax = 1;
    m_nMaxLines = 200;

    m_curveTimer.reset(new QTimer());
    QObject::connect(m_curveTimer.get(),SIGNAL(timeout()),this,SLOT(timerCurveQuery()));
    setCurveTimer(1000);
}

void DataSource::update(QAbstractSeries *series, int nIndex)
{
    if (series) {
        QXYSeries  *xySeries = static_cast<QXYSeries*>(series);

            if(m_listCurve.count() > 1)
                xySeries->replace(m_listCurve);
    }
}

void DataSource::timerCurveQuery()
{
    QPointF pt;
    pt.setX(QDateTime::currentDateTime().toMSecsSinceEpoch());

        qreal data = m_plc->readInt();
        m_dYCurveMax = qMax(data, m_dYCurveMax);
        pt.setY(data);
        if(m_listCurve.length() > m_nMaxLines)
            m_listCurve.pop_front();

        m_listCurve.push_back(pt);
}

void DataSource::setCurveTimer(int nMSec)
{
    m_curveTimer->stop();
    m_curveTimer->start(nMSec);
}


void DataSource::setMaxLines(int nLines)
{
    m_nMaxLines = nLines;
}

QDateTime DataSource::getAxisMax()
{
    QDateTime dt = QDateTime::currentDateTime();
       if( m_listCurve.count() > 1)
            return  dt.fromMSecsSinceEpoch((qint64)m_listCurve.back().rx());

    return dt;
}

QDateTime DataSource::getAxisMin()
{
    QDateTime dt = QDateTime::currentDateTime().addSecs(-10);

        if( m_listCurve.count() > 1)
            return  dt.fromMSecsSinceEpoch((qint64)m_listCurve[0].rx());

   return dt;
}



double DataSource::getCurveYMax()
{
        return m_dYCurveMax *1.05;
}
