/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Charts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DATASOURCE_H
#define DATASOURCE_H

#include <QtCore/QObject>
#include <QtCharts/QAbstractSeries>
#include <QTimer>
#include <memory>
#include <QList>
#include <QPointF>
#include <QDateTime>
#include "plcman.h"

QT_BEGIN_NAMESPACE
class QQuickView;
QT_END_NAMESPACE

QT_CHARTS_USE_NAMESPACE

class DataSource : public QObject
{
    Q_OBJECT
public:
    explicit DataSource(QQuickView *appViewer, QObject *parent = 0);

    void setPlc(PlcMan* plc ){m_plc = plc;}

    Q_INVOKABLE   void setCurveTimer(int nMSec);

    Q_INVOKABLE   QDateTime  getAxisMax();
    Q_INVOKABLE   QDateTime  getAxisMin();

    Q_INVOKABLE   double    getCurveYMax();

    Q_INVOKABLE   void setMaxLines(int nLines);

Q_SIGNALS:

public slots:
    void update(QAbstractSeries *series, int nIndex);
    void timerCurveQuery();
private:
    QQuickView *m_appViewer;
    int m_nShowCurve;

    std::shared_ptr<QTimer> m_curveTimer;
    QList<QPointF> m_listCurve;

    std::vector<QList<QPointF>> m_data;

    PlcMan* m_plc;
    double       m_dYCurveMax;
    double       m_dYTempMax;
    int m_nMaxLines;
};

#endif // DATASOURCE_H
